@@ -1,7 +1,7 @@
 /*
  * buflist-mouse.c - mouse actions for buflist
  *
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -87,7 +87,11 @@ buflist_focus_cb (const void *pointer, void *data, struct t_hashtable *info)
 end:
     /* get list of keys */
     keys = weechat_hdata_get_string (buflist_hdata_buffer, "var_keys");
-    list_keys = weechat_string_split (keys, ",", 0, 0, &num_keys);
+    list_keys = weechat_string_split (keys, ",", NULL,
+                                      WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                      | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                      | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                      0, &num_keys);
     if (!list_keys)
         return info;
 
@@ -143,7 +147,7 @@ end:
 
     /* add pointer and plugin name */
     snprintf (str_value, sizeof (str_value),
-              "0x%lx", (long unsigned int)ptr_buffer);
+              "0x%lx", (unsigned long)ptr_buffer);
     weechat_hashtable_set (info, "pointer", str_value);
     weechat_hashtable_set (info, "plugin",
                            weechat_buffer_get_string (ptr_buffer, "plugin"));
@@ -221,7 +225,7 @@ buflist_hsignal_cb (const void *pointer, void *data, const char *signal,
     struct t_gui_buffer *ptr_buffer;
     char *error, str_command[1024];
     long number, number2;
-    long unsigned int value;
+    unsigned long value;
     int rc, current_buffer_number;
 
     /* make C compiler happy */
@@ -331,8 +335,8 @@ buflist_mouse_init ()
                             &buflist_focus_cb, NULL, NULL);
     }
 
-    weechat_hook_hsignal(BUFLIST_MOUSE_HSIGNAL,
-                         &buflist_hsignal_cb, NULL, NULL);
+    weechat_hook_hsignal (BUFLIST_MOUSE_HSIGNAL,
+                          &buflist_hsignal_cb, NULL, NULL);
 
     return 1;
 }
