@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_RELAY_RAW_H
@@ -24,13 +24,13 @@
 
 #include "relay-client.h"
 
-#define RELAY_RAW_BUFFER_NAME     "relay_raw"
-#define RELAY_RAW_PREFIX_RECV     "-->"
-#define RELAY_RAW_PREFIX_SEND     "<--"
+#define RELAY_RAW_BUFFER_NAME "relay_raw"
+#define RELAY_RAW_PREFIX_RECV "-->"
+#define RELAY_RAW_PREFIX_SEND "<--"
 
-#define RELAY_RAW_FLAG_RECV     1
-#define RELAY_RAW_FLAG_SEND     2
-#define RELAY_RAW_FLAG_BINARY   4
+#define RELAY_RAW_FLAG_RECV   (1 << 0)
+#define RELAY_RAW_FLAG_SEND   (1 << 1)
+#define RELAY_RAW_FLAG_BINARY (1 << 2)
 
 struct t_relay_raw_message
 {
