@@ -1,7 +1,7 @@
 /*
- * script.c - scripts manager for WeeChat
+ * script.c - script manager for WeeChat
  *
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2020 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -27,6 +27,7 @@
 
 #include "../weechat-plugin.h"
 #include "script.h"
+#include "script-action.h"
 #include "script-buffer.h"
 #include "script-command.h"
 #include "script-completion.h"
@@ -37,7 +38,7 @@
 
 
 WEECHAT_PLUGIN_NAME(SCRIPT_PLUGIN_NAME);
-WEECHAT_PLUGIN_DESCRIPTION(N_("Scripts manager"));
+WEECHAT_PLUGIN_DESCRIPTION(N_("Script manager"));
 WEECHAT_PLUGIN_AUTHOR("Sébastien Helleu <flashcode@flashtux.org>");
 WEECHAT_PLUGIN_VERSION(WEECHAT_VERSION);
 WEECHAT_PLUGIN_LICENSE(WEECHAT_LICENSE);
@@ -97,6 +98,32 @@ script_language_search_by_extension (const char *extension)
     return -1;
 }
 
+/*
+ * Checks if download of scripts is enabled.
+ *
+ * Returns:
+ *   0: download NOT enabled (an error is displayed if display_error is 1)
+ *   1: download enabled
+ */
+
+int
+script_download_enabled (int display_error)
+{
+    if (weechat_config_boolean (script_config_scripts_download_enabled))
+        return 1;
+
+    if (display_error)
+    {
+        /* download not enabled: display an error */
+        weechat_printf (NULL,
+                        _("%s%s: download of scripts is disabled by default; "
+                          "see /help script.scripts.download_enabled"),
+                        weechat_prefix ("error"),
+                        SCRIPT_PLUGIN_NAME);
+    }
+    return 0;
+}
+
 /*
  * Builds download URL (to use with hook_process or hook_process_hashtable).
  *
@@ -362,12 +389,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     script_mouse_init ();
 
     if (script_repo_file_exists ())
-    {
-        if (!script_repo_file_is_uptodate ())
-            script_repo_file_update (0);
-        else
-            script_repo_file_read (0);
-    }
+        script_repo_file_read (0);
 
     if (script_buffer)
         script_buffer_refresh (1);
@@ -399,5 +421,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
 
     script_config_free ();
 
+    script_action_end ();
+
     return WEECHAT_RC_OK;
 }
